@@ -55,7 +55,6 @@ class Project:
         self.config = Config(
             self.rootdir,
             self.config_path,
-            fetch_styles=fetch_styles,
         )
 
         (
@@ -68,6 +67,9 @@ class Project:
             self.rootdir,
         )
 
+        if fetch_styles:
+            self.config.load_style()
+
         if init_tree:
             self.tree = Tree(self.rootdir)
 
